@@ -5,22 +5,20 @@ SET extra_float_digits=-3;
 SELECT * FROM pgr_withPointsDD(
   'SELECT id, source, target, cost, reverse_cost FROM edges ORDER BY id',
   'SELECT pid, edge_id, fraction, side from pointsOfInterest',
-  -1, 3.3,
-  driving_side => 'r',
+  -1, 3.3, 'r',
   details => true);
 /* -- q3 */
 SELECT * FROM pgr_withPointsDD(
   'SELECT id, source, target, cost, reverse_cost FROM edges ORDER BY id',
   'SELECT pid, edge_id, fraction, side from pointsOfInterest',
-  ARRAY[-1, 16], 3.3,
-  driving_side => 'l',
+  ARRAY[-1, 16], 3.3, 'l',
   equicost => true);
 /* -- q4 */
 SELECT * FROM pgr_withPointsDD(
   'SELECT id, source, target, cost, reverse_cost FROM edges ORDER BY id',
   'SELECT pid, edge_id, fraction, side from pointsOfInterest',
-  -1, 3.3,
-  driving_side => 'b',
+  -1, 3.3, 'b',
+  directed => false,
   details => true);
 /* -- q5 */
 SELECT * FROM pgr_withPointsDD(
@@ -31,7 +29,6 @@ SELECT * FROM pgr_withPointsDD(
         (SELECT ST_POINT(2.9, 1.8)),
         0.5, cap => 2)
   $p$,
-  ARRAY[-1, -2], 2.3,
-  driving_side => 'r',
+  ARRAY[-1, -2], 2.3, 'r',
   details => true);
 /* -- q6 */
