@@ -58,7 +58,7 @@ class Pgr_breadthFirstSearch {
             std::vector<E> visited_order;
 
             if (graph.has_vertex(source)) {
-                results.push_back({source, 0, source, -1, 0.0, 0.0});
+                results.push_back({source, 0, source, source, -1, 0.0, 0.0});
                 boost::breadth_first_search(graph.graph,
                                             graph.get_V(source),
                                             visitor(bfs_visitor(visited_order)));
@@ -94,8 +94,9 @@ class Pgr_breadthFirstSearch {
 
              if (max_depth >= depth[v]) {
                  results.push_back({
-                     source,
+                         source,
                          depth[v],
+                         graph[u].id,
                          graph[v].id,
                          graph[edge].id,
                          graph[edge].cost,
