@@ -1,6 +1,9 @@
 /*PGR-GNU*****************************************************************
 File: postgres_connection.h
 
+Copyright (c) 2015 pgRouting developers
+Mail: project@pgrouting.org
+
 Copyright (c) 2015 Celia Virginia Vergara Castillo
 vicky_vergara@hotmail.com
 
@@ -25,13 +28,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #define INCLUDE_C_COMMON_POSTGRES_CONNECTION_H_
 #pragma once
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 #include <postgres.h>
 #include <executor/spi.h>
 #include <funcapi.h>
-#include <utils/builtins.h>  // for text_to_cstring
+#include <utils/builtins.h>
 #include <access/htup_details.h>
 #include <fmgr.h>
+#include <utils/array.h>
+#include <catalog/pg_type.h>
 
 
 void pgr_send_error(int errcode);
@@ -40,4 +48,8 @@ void pgr_SPI_connect(void);
 SPIPlanPtr pgr_SPI_prepare(char* sql);
 Portal pgr_SPI_cursor_open(SPIPlanPtr SPIplan);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif  // INCLUDE_C_COMMON_POSTGRES_CONNECTION_H_
