@@ -1,6 +1,9 @@
 /*PGR-GNU*****************************************************************
 File: restrict_t.h
 
+Copyright (c) 2015 pgRouting developers
+Mail: project@pgrouting.org
+
 Copyright (c) 2015 Celia Virginia Vergara Castillo
 Mail: vicky_vergara@hotmail.com
 
@@ -37,7 +40,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 struct Restriction_t {
     double cost;
     int64_t * via;
-    uint64_t via_size;
+    size_t via_size;
 };
 
 #endif  // INCLUDE_C_TYPES_RESTRICTION_T_H_
