@@ -1,6 +1,10 @@
 /*PGR-GNU*****************************************************************
 
 File: basePath_SSEC.hpp
+
+Copyright (c) 2015 pgRouting developers
+Mail: project@pgrouting.org
+
 Copyright (c) 2015 Celia Virginia Vergara Castillo
 vicky_vergara@hotmail.com
 
@@ -38,10 +42,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <boost/graph/adjacency_list.hpp>
 
 #include "c_types/path_rt.h"
+#include "c_types/mst_rt.h"
 #include "cpp_common/path_t.h"
 #include "cpp_common/pgr_base_graph.hpp"
 #include "cpp_common/rule.h"
 
+namespace pgrouting {
 
 class Path {
     typedef std::deque< Path_t >::iterator pthIt;
@@ -59,7 +65,6 @@ class Path {
     Path(int64_t s_id, int64_t e_id)
         : m_start_id(s_id), m_end_id(e_id), m_tot_cost(0)
     {}
-    Path(const Path&) = default;
 
     int64_t start_id() const {return m_start_id;}
     void start_id(int64_t value) {m_start_id = value;}
@@ -130,13 +135,7 @@ class Path {
     void append(const Path &other);
     void empty_path(unsigned int d_vertex);
 
-    void get_pg_dd_path(
-            Path_rt **ret_path,
-            size_t &sequence) const;
-
-    void get_pg_ksp_path(
-            Path_rt **ret_path,
-            size_t &sequence, int routeId) const;
+    void get_pg_nksp_path(Path_rt**, size_t&) const;
 
     void get_pg_turn_restricted_path(
             Path_rt **ret_path,
@@ -146,6 +145,9 @@ class Path {
             Path_rt **postgres_data,
             size_t &sequence) const;
 
+    void generate_tuples(MST_rt**, size_t&) const;
+    friend size_t collapse_paths(MST_rt**, const std::deque<Path>&);
+
     friend size_t collapse_paths(
             Path_rt **ret_path,
             const std::deque< Path > &paths);
@@ -174,7 +176,7 @@ class Path {
                     push_back(
                             {graph[i].id,
                             edge_id, cost,
-                            distances[i]});
+                            distances[i], graph[predecessors[i]].id});
                 }
             }
         }
@@ -198,26 +200,29 @@ class Path {
                         graph.graph);
 
                 if (p.edge == -1) {
-                    path.push_back({m_end_id, -1, 0, 0});
+                    /* TODO(v4) add correct predecessor node */
+                    path.push_back({m_end_id, -1, 0, 0, 0});
                 } else {
                     for ( ; ei != ei_end; ++ei) {
                         if (graph[*ei].id == p.edge) {
                             auto cost = graph[*ei].cost;
-                            push_back({p.node, p.edge, cost, 0});
+                            /* TODO(v4) add correct predecessor node */
+                            push_back({p.node, p.edge, cost, 0, 0});
                         }
                     }
                 }
-//                last_node = p.node;
+                //                last_node = p.node;
             }
             recalculate_agg_cost();
 
             if (only_cost) {
                 path.clear();
+                /* TODO(v4) add correct predecessor node */
                 path.push_back(
                         {m_end_id,
                         -1,
                         m_tot_cost,
-                        m_tot_cost});
+                        m_tot_cost, 0});
             }
         }
 
@@ -266,11 +271,13 @@ class Path {
              * only_cost
              */
             if (v_target != predecessors[v_target]) {
+                /* TODO(v4) add correct predecessor node */
                 push_front(
                         {graph.graph[v_target].id,
                         -1,
                         distances[v_target],
-                        distances[v_target]});
+                        distances[v_target],
+                        0});
             }
             return;
         }
@@ -299,9 +306,10 @@ class Path {
         /*
          * the last stop is the target
          */
+        /* TODO(v4) add correct predecessor node */
         push_front(
                 {graph.graph[target].id, -1,
-                0,  distances[target]});
+                0,  distances[target], 0});
 
         /*
          * get the path
@@ -321,11 +329,12 @@ class Path {
                 graph.get_edge_id(predecessors[target], target, cost)
                 : graph.get_edge_id(target, predecessors[target], cost);
 
+            /* TODO(v4) add correct predecessor node */
             push_front({
                     vertex_id,
                     edge_id,
                     cost,
-                    distances[target] - cost});
+                    distances[target] - cost, 0});
             target = predecessors[target];
         }
 
@@ -333,5 +342,6 @@ class Path {
     }
 };
 
+}  // namespace pgrouting
 
 #endif  // INCLUDE_CPP_COMMON_BASEPATH_SSEC_HPP_
