@@ -1,6 +1,9 @@
 /*PGR-GNU*****************************************************************
  *
 
+Copyright (c) 2017 pgRouting developers
+Mail: project@pgrouting.org
+
 Copyright (c) 2017 Celia Virginia Vergara Castillo
 vicky_vergara@hotmail.com
 
@@ -39,7 +42,6 @@ namespace pgrouting {
 class Identifier {
  public:
      Identifier() = default;
-     Identifier(const Identifier &v) = default;
      Identifier(const size_t _idx, const int64_t _id);
 
      int64_t id() const;
