@@ -1,6 +1,9 @@
 /*PGR-GNU*****************************************************************
 File: path_t.h
 
+Copyright (c) 2015 pgRouting developers
+Mail: project@pgrouting.org
+
 Copyright (c) 2015 Celia Virginia Vergara Castillo
 Mail: vicky_vergara@hotmail.com
 
@@ -30,14 +33,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <stdint.h>
 
-/*
- * This one is for processing
- */
 struct Path_t {
     int64_t node;
     int64_t edge;
     double cost;
     double agg_cost;
+    int64_t pred;
 };
 
 #endif  // INCLUDE_CPP_COMMON_PATH_T_H_
