@@ -1,6 +1,9 @@
 /*PGR-GNU*****************************************************************
 File: pgr_palloc.hpp
 
+Copyright (c) 2015 pgRouting developers
+Mail: project@pgrouting.org
+
 Copyright (c) 2015 Celia Virginia Vergara Castillo
 Mail: vicky_vergara@hotmail.com
 
@@ -45,6 +48,8 @@ SPI_pfree(void *pointer);
 }
 
 
+namespace pgrouting {
+
 /*! \fn pgr_alloc(std::size_t size, T *ptr)
 
 \brief allocates memory
@@ -84,4 +89,6 @@ pgr_free(T* ptr) {
 char *
 pgr_msg(const std::string &msg);
 
+}  // namespace pgrouting
+
 #endif  // INCLUDE_CPP_COMMON_PGR_ALLOC_HPP_
