@@ -1,5 +1,8 @@
 /*PGR-GNU*****************************************************************
  *
+Copyright (c) 2015 pgRouting developers
+Mail: project@pgrouting.org
+
 Copyright (c) 2015 Celia Virginia Vergara Castillo
 vicky_vergara@hotmail.com
 ------
@@ -119,7 +122,7 @@ Vector of unique vertices of the graph
 ~~~~{.c}
 size_t total_edges;
 Edge_t *my_edges = NULL;
-pgr_get_edges(edges_sql, &my_edges, &total_tuples);
+pgr_get_edges(edges_sql, &my_edges, &total_tuples, true, false, &err_msg);
 std::vector< Basic_Vertex > vertices(pgrouting::extract_vertices(my_edges));
 ~~~~
 There are several ways to initialize the graph
