@@ -1,6 +1,9 @@
 /*PGR-GNU*****************************************************************
  *
 
+Copyright (c) 2015 pgRouting developers
+Mail: project@pgrouting.org
+
  Copyright (c) 2015 Celia Virginia Vergara Castillo
  vicky_vergara@hotmail.com
 
@@ -40,7 +43,6 @@ namespace pgrouting {
 class XY_vertex {
  public:
   XY_vertex() = default;
-  XY_vertex(const XY_vertex &) = default;
   XY_vertex(const int64_t _id, double _x, double _y) :
       id(_id), point(_x, _y) {
       }
