@@ -1,6 +1,9 @@
 /*PGR-GNU*****************************************************************
 File: details.hpp
 
+Copyright (c) 2018 pgRouting developers
+Mail: project@pgrouting.org
+
 Copyright (c) 2018 Vicky Vergara
 
 
@@ -37,8 +40,7 @@ std::vector<int64_t>
 clean_vids(std::vector<int64_t> vids);
 
 std::vector<MST_rt>
-get_no_edge_graph_result(
-        const std::vector<int64_t>& vids);
+get_no_edge_graph_result(const std::vector<int64_t> &vids);
 
 }  // namespace details
 }  // namespace pgrouting
