@@ -129,6 +129,30 @@ COST 100
 ROWS 1000;
 
 
+-- combinations
+--v3.2
+CREATE FUNCTION pgr_bdAstarCost(
+    TEXT,     -- edges_sql (required)
+    TEXT,     -- combinations_sql (required)
+
+    directed BOOLEAN DEFAULT true,
+    heuristic INTEGER DEFAULT 5,
+    factor NUMERIC DEFAULT 1.0,
+    epsilon NUMERIC DEFAULT 1.0,
+
+    OUT start_vid BIGINT,
+    OUT end_vid BIGINT,
+    OUT agg_cost FLOAT)
+RETURNS SETOF RECORD AS
+$BODY$
+    SELECT a.start_vid, a.end_vid, a.agg_cost
+    FROM _pgr_bdAstar(_pgr_get_statement($1), _pgr_get_statement($2), $3, $4, $5::FLOAT, $6::FLOAT, true) AS a;
+$BODY$
+LANGUAGE sql VOLATILE STRICT
+COST 100
+ROWS 1000;
+
+
 -- COMMENTS
 
 COMMENT ON FUNCTION pgr_bdAstarCost(TEXT, BIGINT, BIGINT, BOOLEAN, INTEGER, NUMERIC, NUMERIC)
@@ -193,3 +217,18 @@ IS 'pgr_bdAstarCost(Many to Many)
 - Documentation:
   - ${PROJECT_DOC_LINK}/pgr_bdAstarCost.html
 ';
+
+
+COMMENT ON FUNCTION pgr_bdAstarCost(TEXT, TEXT, BOOLEAN, INTEGER, NUMERIC, NUMERIC)
+IS 'pgr_bdAstarCost(Combinations)
+- Parameters:
+  - Edges SQL with columns: id, source, target, cost [, reverse_cost], x1, y1, x2, y2
+  - Combinations SQL with columns: source, target
+- Optional Parameters:
+  - directed := true
+  - heuristic := 5
+  - factor := 1
+  - epsilon := 1
+- Documentation:
+  - ${PROJECT_DOC_LINK}/pgr_bdAstarCost.html
+';
