@@ -43,7 +43,7 @@ CREATE FUNCTION pgr_edmondsKarp(
     OUT residual_capacity BIGINT)
   RETURNS SEtoF RECORD AS
   $BODY$
-        SELECT *
+        SELECT seq, edge_id, source, target, flow, residual_capacity
         FROM _pgr_maxflow(_pgr_get_statement($1), ARRAY[$2]::BIGINT[], ARRAY[$3]::BIGINT[], 3);
   $BODY$
   LANGUAGE sql VOLATILE STRICT;
@@ -64,7 +64,7 @@ CREATE FUNCTION pgr_edmondsKarp(
     OUT residual_capacity BIGINT)
   RETURNS SEtoF RECORD AS
   $BODY$
-        SELECT *
+        SELECT seq, edge_id, source, target, flow, residual_capacity
         FROM _pgr_maxflow(_pgr_get_statement($1), ARRAY[$2]::BIGINT[], $3::BIGINT[], 3);
   $BODY$
   LANGUAGE sql VOLATILE STRICT;
@@ -85,7 +85,7 @@ CREATE FUNCTION pgr_edmondsKarp(
     OUT residual_capacity BIGINT)
   RETURNS SEtoF RECORD AS
   $BODY$
-        SELECT *
+        SELECT seq, edge_id, source, target, flow, residual_capacity
         FROM _pgr_maxflow(_pgr_get_statement($1), $2::BIGINT[], ARRAY[$3]::BIGINT[], 3);
   $BODY$
   LANGUAGE sql VOLATILE STRICT;
@@ -106,7 +106,7 @@ CREATE FUNCTION pgr_edmondsKarp(
     OUT residual_capacity BIGINT)
   RETURNS SEtoF RECORD AS
   $BODY$
-        SELECT *
+        SELECT seq, edge_id, source, target, flow, residual_capacity
         FROM _pgr_maxflow(_pgr_get_statement($1), $2::BIGINT[], $3::BIGINT[], 3);
   $BODY$
   LANGUAGE sql VOLATILE STRICT;
@@ -125,7 +125,7 @@ CREATE FUNCTION pgr_edmondsKarp(
     OUT residual_capacity BIGINT)
   RETURNS SEtoF RECORD AS
   $BODY$
-        SELECT *
+        SELECT seq, edge_id, source, target, flow, residual_capacity
         FROM _pgr_maxflow(_pgr_get_statement($1), _pgr_get_statement($2), 3);
   $BODY$
   LANGUAGE sql VOLATILE STRICT;
