@@ -2,6 +2,9 @@
 
 FILE: pgr_assert.cpp
 
+Copyright (c) 2014 pgRouting developers
+Mail: project@pgrouting.org
+
 Copyright 2015~  Vicky Vergara <vicky_vergara@hotmail.com>
 Copyright 2014 Stephen Woodbridge <woodbri@imaptools.com>
 Mail: project@pgrouting.org
@@ -33,9 +36,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <execinfo.h>
 #endif
 
-#include <exception>
 #include <string>
-#include <utility>
+#include <exception>
 
 
 std::string get_backtrace() {
@@ -70,5 +72,5 @@ const char* AssertFailedException::what() const throw() {
 }
 
 AssertFailedException::AssertFailedException(std::string msg) :
-    str(std::move(msg)) {}
+    str(msg) {}
 
