@@ -1,9 +1,14 @@
 /*PGR-GNU*****************************************************************
 File: many_to_dist_driving_distance.c
 
-Copyright (c) 2015 Celia Virginia Vergara Castillo
-Mail: vicky_Vergara@hotmail.com
+Copyright (c) 2015 pgRouting developers
+Mail: project@pgrouting.org
 
+Copyright (c) 2015 Celia Virginia Vergara Castillo
+Mail: vicky at erosion.dev
+
+Copyright (c) 2023 Aryan Gupta
+guptaaryan1010 AT gmail.com
 ------
 
 This program is free software; you can redistribute it and/or modify
@@ -24,39 +29,44 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <stdbool.h>
 #include "c_common/postgres_connection.h"
-#include "utils/array.h"
 
-#include "c_types/path_rt.h"
+#include "c_types/mst_rt.h"
 #include "c_common/debug_macro.h"
 #include "c_common/e_report.h"
 #include "c_common/time_msg.h"
 
-#include "c_common/edges_input.h"
-#include "c_common/arrays_input.h"
+#include "c_common/pgdata_getters.h"
 #include "drivers/driving_distance/drivedist_driver.h"
 
 
 PGDLLEXPORT Datum _pgr_drivingdistance(PG_FUNCTION_ARGS);
 PG_FUNCTION_INFO_V1(_pgr_drivingdistance);
 
+PGDLLEXPORT Datum _pgr_drivingdistancev4(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(_pgr_drivingdistancev4);
 
 static
 void process(
-        char* sql,
+        char* edges_sql,
         ArrayType *starts,
         float8 distance,
         bool directed,
         bool equicost,
-        Path_rt **result_tuples,
+        MST_rt **result_tuples,
         size_t *result_count) {
     pgr_SPI_connect();
+    char* log_msg = NULL;
+    char* notice_msg = NULL;
+    char* err_msg = NULL;
 
     size_t size_start_vidsArr = 0;
-    int64_t* start_vidsArr = pgr_get_bigIntArray(&size_start_vidsArr, starts);
+    int64_t* start_vidsArr = pgr_get_bigIntArray(&size_start_vidsArr, starts, false, &err_msg);
+    throw_error(err_msg, "While getting start vids");
 
     Edge_t *edges = NULL;
     size_t total_tuples = 0;
-    pgr_get_edges(sql, &edges, &total_tuples);
+    pgr_get_edges(edges_sql, &edges, &total_tuples, true, false, &err_msg);
+    throw_error(err_msg, edges_sql);
 
     if (total_tuples == 0) {
         return;
@@ -64,10 +74,7 @@ void process(
 
     PGR_DBG("Starting timer");
     clock_t start_t = clock();
-    char* log_msg = NULL;
-    char* notice_msg = NULL;
-    char* err_msg = NULL;
-    do_pgr_driving_many_to_dist(
+    pgr_do_drivingdist(
             edges, total_tuples,
             start_vidsArr, size_start_vidsArr,
             distance,
@@ -78,7 +85,7 @@ void process(
             &notice_msg,
             &err_msg);
 
-    time_msg("processing pgr_drivingDistance()",
+    time_msg("processing pgr_drivingDistance",
             start_t, clock());
 
     if (err_msg && (*result_tuples)) {
@@ -100,14 +107,12 @@ void process(
 
 
 PGDLLEXPORT Datum
-_pgr_drivingdistance(PG_FUNCTION_ARGS) {
+_pgr_drivingdistancev4(PG_FUNCTION_ARGS) {
     FuncCallContext     *funcctx;
     TupleDesc            tuple_desc;
 
-    /**********************************************************************/
-    Path_rt* result_tuples = 0;
+    MST_rt  *result_tuples = 0;
     size_t result_count = 0;
-    /**********************************************************************/
 
     if (SRF_IS_FIRSTCALL()) {
         MemoryContext   oldcontext;
@@ -115,9 +120,6 @@ _pgr_drivingdistance(PG_FUNCTION_ARGS) {
         funcctx = SRF_FIRSTCALL_INIT();
         oldcontext = MemoryContextSwitchTo(funcctx->multi_call_memory_ctx);
 
-        /**********************************************************************/
-
-        PGR_DBG("Calling driving_many_to_dist_driver");
         process(
                 text_to_cstring(PG_GETARG_TEXT_P(0)),
                 PG_GETARG_ARRAYTYPE_P(1),
@@ -126,7 +128,6 @@ _pgr_drivingdistance(PG_FUNCTION_ARGS) {
                 PG_GETARG_BOOL(4),
                 &result_tuples, &result_count);
 
-        /**********************************************************************/
 
         funcctx->max_calls = result_count;
 
@@ -146,7 +147,7 @@ _pgr_drivingdistance(PG_FUNCTION_ARGS) {
     funcctx = SRF_PERCALL_SETUP();
 
     tuple_desc = funcctx->tuple_desc;
-    result_tuples = (Path_rt*) funcctx->user_fctx;
+    result_tuples = (MST_rt*) funcctx->user_fctx;
 
     if (funcctx->call_cntr < funcctx->max_calls) {
         HeapTuple    tuple;
@@ -154,8 +155,7 @@ _pgr_drivingdistance(PG_FUNCTION_ARGS) {
         Datum *values;
         bool* nulls;
 
-        /**********************************************************************/
-        size_t numb = 6;
+        size_t numb = 8;
         values = palloc(numb * sizeof(Datum));
         nulls = palloc(numb * sizeof(bool));
 
@@ -164,13 +164,14 @@ _pgr_drivingdistance(PG_FUNCTION_ARGS) {
             nulls[i] = false;
         }
         values[0] = Int32GetDatum(funcctx->call_cntr + 1);
-        values[1] = Int64GetDatum(result_tuples[funcctx->call_cntr].start_id);
-        values[2] = Int64GetDatum(result_tuples[funcctx->call_cntr].node);
-        values[3] = Int64GetDatum(result_tuples[funcctx->call_cntr].edge);
-        values[4] = Float8GetDatum(result_tuples[funcctx->call_cntr].cost);
-        values[5] = Float8GetDatum(result_tuples[funcctx->call_cntr].agg_cost);
+        values[1] = Int64GetDatum(result_tuples[funcctx->call_cntr].depth);
+        values[2] = Int64GetDatum(result_tuples[funcctx->call_cntr].from_v);
+        values[3] = Int64GetDatum(result_tuples[funcctx->call_cntr].pred);
+        values[4] = Int64GetDatum(result_tuples[funcctx->call_cntr].node);
+        values[5] = Int64GetDatum(result_tuples[funcctx->call_cntr].edge);
+        values[6] = Float8GetDatum(result_tuples[funcctx->call_cntr].cost);
+        values[7] = Float8GetDatum(result_tuples[funcctx->call_cntr].agg_cost);
 
-        /**********************************************************************/
         tuple = heap_form_tuple(tuple_desc, values, nulls);
         result = HeapTupleGetDatum(tuple);
 
@@ -183,3 +184,85 @@ _pgr_drivingdistance(PG_FUNCTION_ARGS) {
     }
 }
 
+
+/* Old code starts here
+ * TODO(v4) remove old code
+ * its code that is used when there is an old version of SQL 3.5 and under
+ */
+PGDLLEXPORT Datum
+_pgr_drivingdistance(PG_FUNCTION_ARGS) {
+    FuncCallContext     *funcctx;
+    TupleDesc            tuple_desc;
+
+    MST_rt  *result_tuples = 0;
+    size_t result_count = 0;
+
+    if (SRF_IS_FIRSTCALL()) {
+        MemoryContext   oldcontext;
+
+        funcctx = SRF_FIRSTCALL_INIT();
+        oldcontext = MemoryContextSwitchTo(funcctx->multi_call_memory_ctx);
+
+
+        PGR_DBG("Calling driving_many_to_dist_driver");
+        process(
+                text_to_cstring(PG_GETARG_TEXT_P(0)),
+                PG_GETARG_ARRAYTYPE_P(1),
+                PG_GETARG_FLOAT8(2),
+                PG_GETARG_BOOL(3),
+                PG_GETARG_BOOL(4),
+                &result_tuples, &result_count);
+
+
+        funcctx->max_calls = result_count;
+
+        funcctx->user_fctx = result_tuples;
+        if (get_call_result_type(fcinfo, NULL, &tuple_desc)
+                != TYPEFUNC_COMPOSITE)
+            ereport(ERROR,
+                    (errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
+                     errmsg("function returning record called in context "
+                         "that cannot accept type record")));
+
+        funcctx->tuple_desc = tuple_desc;
+
+        MemoryContextSwitchTo(oldcontext);
+    }
+
+    funcctx = SRF_PERCALL_SETUP();
+
+    tuple_desc = funcctx->tuple_desc;
+    result_tuples = (MST_rt*) funcctx->user_fctx;
+
+    if (funcctx->call_cntr < funcctx->max_calls) {
+        HeapTuple    tuple;
+        Datum        result;
+        Datum *values;
+        bool* nulls;
+
+        size_t numb = 6;
+        values = palloc(numb * sizeof(Datum));
+        nulls = palloc(numb * sizeof(bool));
+
+        size_t i;
+        for (i = 0; i < numb; ++i) {
+            nulls[i] = false;
+        }
+        values[0] = Int32GetDatum((int32_t)funcctx->call_cntr + 1);
+        values[1] = Int64GetDatum(result_tuples[funcctx->call_cntr].from_v);
+        values[2] = Int64GetDatum(result_tuples[funcctx->call_cntr].node);
+        values[3] = Int64GetDatum(result_tuples[funcctx->call_cntr].edge);
+        values[4] = Float8GetDatum(result_tuples[funcctx->call_cntr].cost);
+        values[5] = Float8GetDatum(result_tuples[funcctx->call_cntr].agg_cost);
+
+        tuple = heap_form_tuple(tuple_desc, values, nulls);
+        result = HeapTupleGetDatum(tuple);
+
+        pfree(values);
+        pfree(nulls);
+
+        SRF_RETURN_NEXT(funcctx, result);
+    } else {
+        SRF_RETURN_DONE(funcctx);
+    }
+}
